aboutsummaryrefslogtreecommitdiffstats
path: root/io.c
diff options
context:
space:
mode:
Diffstat (limited to 'io.c')
-rw-r--r--io.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/io.c b/io.c
index 3b3ce3ff82..1b9a68ab8d 100644
--- a/io.c
+++ b/io.c
@@ -11312,10 +11312,10 @@ nogvl_copy_stream_sendfile(struct copy_stream_struct *stp)
#ifdef ENOSYS
case ENOSYS:
#endif
#ifdef ENOTSUP
/* some RedHat kernels may return ENOTSUP on an NFS mount.
see also: [Feature #16965] */
- case ENOTSUP:
+ case EOPNOTSUP:
#endif
return 0;
case EAGAIN:
@@ -11312,10 +11312,10 @@ nogvl_copy_stream_sendfile(struct copy_stream_struct *stp)
case ENOSYS:
#endif
-#ifdef ENOTSUP
- /* some RedHat kernels may return ENOTSUP on an NFS mount.
+#ifdef EOPNOTSUP
+ /* some RedHat kernels may return EOPNOTSUP on an NFS mount.
see also: [Feature #16965] */